General
-----

* Add `_` prefix to getters and setters

DNS
-----

* `domain.resource.update`
* Fix `Record.from_api_dict` behavior for empty-string port/weight

Linode
-----

* `linode.config.delete`
* Make clear single-user-mode setter
* Add Linode class attributes for `status` attribute (up, down, ?)

Nodebalacer
-----

Implement all Nodebalancer functionality
